@@ -1457,7 +1457,7 @@ def test_numpy_array_conversion(Qs):
     Q = Qs[Qs_nonnan][:12]  # Select first 3x4=12 non-nan elements in Qs
     assert Q.dtype == np.dtype(np.quaternion)
     q = quaternion.as_float_array(Q)  # View as array of floats
-    assert q.dtype == np.dtype(np.float)
+    assert q.dtype == np.dtype(np.float64)
     assert q.shape == (12, 4)  # This is the expected shape
     for j in range(12):
         for k in range(4):  # Check each component individually
@@ -1465,7 +1465,7 @@ def test_numpy_array_conversion(Qs):
     assert np.array_equal(quaternion.as_quat_array(q), Q)  # Check that we can go backwards
     # Next, see how that works if I flatten the q array
     q = q.flatten()
-    assert q.dtype == np.dtype(np.float)
+    assert q.dtype == np.dtype(np.float64)
     assert q.shape == (48,)
     for j in range(48):
         assert q[j] == Q[j // 4].components[j % 4]
@@ -1496,6 +1496,27 @@ def test_numpy_array_conversion(Qs):
     assert np.array_equal(quaternion.as_quat_array(q[:, 3:7]), Q)
 
 
+def test_not_implemented():
+    Q = quaternion.quaternion(1.1, 2.2, 3.3, 4.4)
+    class B:
+        pass
+    b = B()
+    with pytest.raises(TypeError):
+        b * Q
+    with pytest.raises(TypeError):
+        Q * b
+    class A:
+        def __init__(self, data: float):
+            self._data = data
+        def __rmul__(self, other):
+            return other * self._data
+        def __mul__(self, other):
+            return self._data * other
+    a = A(1.2)
+    assert a * Q == 1.2 * Q
+    assert Q * a == Q * 1.2
+
+
 @pytest.mark.skipif(not has_scipy, reason="Scipy is not installed")
 def test_integrate_angular_velocity():
     import math
